MethodChannelFlutterAppFunctions class
The MethodChannel-backed implementation of FlutterAppFunctionsPlatform.
- Inheritance
-
- Object
- PlatformInterface
- FlutterAppFunctionsPlatform
- MethodChannelFlutterAppFunctions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The MethodChannel used to communicate with the native side.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
Returns the Android version string, or
nullon non-Android platforms.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited